@@ -124,14 +124,22 @@ class KongAuth(BaseAuth):
     def valid_sign(self,func):
         @wraps(func)
         def _request_sign(*args, **kw):
-            # json.dumps(json_body)+token+noncestr+timestamp 转md5
+            # key认证的token为key，浏览器端因访问不到jwt，可以传username
+            # json.dumps(json_body)+token(或用户名)+noncestr+timestamp 转md5
             sign = request.headers.get('X-MW-Sign') or request.args.get("sign")
-            sign_source_str = f'{request.data.decode()}{g.jwt}' \
+            sign_source_str = f'{request.data.decode()}{g.current_user.uname}' \
                               f'{request.headers.get("X-MW-Noncestr") or request.args.get("noncestr", "")}' \
                               f'{request.headers.get("X-MW-Timestamp") or request.args.get("timestamp", "")}'
             sign_md5 = hashlib.md5(sign_source_str.encode()).hexdigest()
             if sign_md5 == sign:
                 return func(*args, **kw)
+            else:
+                sign_source_str = f'{request.data.decode()}{g.jwt}' \
+                                  f'{request.headers.get("X-MW-Noncestr") or request.args.get("noncestr", "")}' \
+                                  f'{request.headers.get("X-MW-Timestamp") or request.args.get("timestamp", "")}'
+                sign_md5 = hashlib.md5(sign_source_str.encode()).hexdigest()
+                if sign_md5 == sign:
+                    return func(*args, **kw)
             # 没有认证则返回400
             response = make_response({ "error": f'sign error,sign:{sign},noncestr:{request.args.get("noncestr", "")},'
                                                 f'timestamp:{request.args.get("timestamp", "")}'},
